//// [parserFunctionPropertyAssignment4.ts]
var v = { 0<T>() { } };

//// [parserFunctionPropertyAssignment4.js]
var v = { 0: function () { } };
